@@ -16,7 +16,6 @@ package kubeconfigutil
 
 import (
 	"fmt"
-	"io/ioutil"
 	"os"
 	"strings"
 
@@ -38,18 +37,21 @@ type Kubeconfig struct {
 // given by the path argument
 // This will overwrite the kubeconfig given by path when calling WriteKubeconfigFile()
 func NewKubeconfigForPath(path string) (*Kubeconfig, error) {
-	bytes, err := ioutil.ReadFile(path)
+	bytes, err := os.ReadFile(path)
 	if err != nil {
 		return nil, fmt.Errorf("failed to read kubeconfig file: %v", err)
 	}
-	return newKubeconfig(bytes, path, false)
+	return New(bytes, path, false)
 }
 
+// Create kubeconfig file in the temporary directory
 func NewKubeconfig(kubeconfigData []byte) (*Kubeconfig, error) {
-	return newKubeconfig(kubeconfigData, os.ExpandEnv(TemporaryKubeconfigDir), true)
+	return New(kubeconfigData, os.ExpandEnv(TemporaryKubeconfigDir), true)
 }
 
-func newKubeconfig(kubeconfigData []byte, path string, useTmpFile bool) (*Kubeconfig, error) {
+// New creates a new Kubeconfig representation based on the given kubeconfig data
+// the format is validated
+func New(kubeconfigData []byte, path string, useTmpFile bool) (*Kubeconfig, error) {
 	n := &yaml.Node{}
 	if err := yaml.Unmarshal(kubeconfigData, n); err != nil {
 		return nil, err
@@ -150,7 +152,7 @@ func (k *Kubeconfig) WriteKubeconfigFile() (string, error) {
 		}
 
 		// write temporary kubeconfig file
-		file, err = ioutil.TempFile(k.path, "config.*.tmp")
+		file, err = os.CreateTemp(k.path, "config.*.tmp")
 		if err != nil {
 			return "", err
 		}
