@@ -24,7 +24,7 @@ import (
 type StoreKind string
 
 // ValidStoreKinds contains all valid store kinds
-var ValidStoreKinds = sets.NewString(string(StoreKindVault), string(StoreKindFilesystem), string(StoreKindGardener), string(StoreKindGKE), string(StoreKindAzure), string(StoreKindEKS))
+var ValidStoreKinds = sets.NewString(string(StoreKindVault), string(StoreKindFilesystem), string(StoreKindGardener), string(StoreKindGKE), string(StoreKindAzure), string(StoreKindEKS), string(StoreKindRancher))
 
 // ValidConfigVersions contains all valid config versions
 var ValidConfigVersions = sets.NewString("v1alpha1")
@@ -42,6 +42,8 @@ const (
 	StoreKindAzure StoreKind = "azure"
 	// StoreKindEKS is an identifier for the EKS store
 	StoreKindEKS StoreKind = "eks"
+	// StoreKindRancher is an identifier for the Rancher store
+	StoreKindRancher StoreKind = "rancher"
 )
 
 type Config struct {
@@ -106,6 +108,17 @@ type KubeconfigStore struct {
 	// Please check the documentation for each backing provider to see what configuration is
 	// possible here
 	Config interface{} `yaml:"config"`
+	// Cache allows to cache the kubeconfigs in the backing store
+	// + optional
+	Cache *Cache `yaml:"cache"`
+}
+
+// CacheConfig contains the configuration for the cache
+type Cache struct {
+	Kind string `yaml:"kind"`
+	// Config is store-specific configuration for the cache
+	// Check the documentation for each cache to see configuration options
+	Config interface{} `yaml:"config"`
 }
 
 type StoreConfigVault struct {
@@ -204,3 +217,10 @@ type GKEAuthentication struct {
 	// + optional
 	ServiceAccountFilePath *string `yaml:"serviceAccountFilePath"`
 }
+
+type StoreConfigRancher struct {
+	// RancherAddress is the URL of the Rancher API, e.g. https://rancher.example.com/v3
+	RancherAddress string `yaml:"rancherAPIAddress"`
+	// RancherToken is the token used to authenticate against the Rancher API, format: token-12abc:bmjlzslas......x4hv5ptc29wt4sfk
+	RancherToken string `yaml:"rancherToken"`
+}
